import pygame
import os
import thermopi.surfaces as surfaces

# Global variables
SCREEN_SIZE = (720, 720)
FPS = 60
PI = 3.14159265
VALID_SURFACES = [
    'dial'
]
SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))


def main(windowed_mode=False):
    """
    Main looping method.
    :param windowed_mode: boolean to start the game in windowed mode
    """
    pygame.init()
    clock = pygame.time.Clock()
    if windowed_mode:
        window = pygame.display.set_mode(SCREEN_SIZE)
    else:
        window = pygame.display.set_mode(SCREEN_SIZE, pygame.FULLSCREEN)

    # Starts the program with the surface 'dial' as the default
    surface = getattr(globals()['surfaces'], 'dial').Surface(SCREEN_SIZE)
    running = True
    while running:
        clock.tick(FPS)
        surface.update()

        window.blit(surface, surface.get_rect())

        if not surface.running:
            if surface.quit:
                break
            # Switch the surface to a new surface
            next_surface = surface.next_surface
            if next_surface not in VALID_SURFACES:
                raise Exception('Given surface is not a valid surface!')
            surface = getattr(globals()['surfaces'], next_surface).Surface(SCREEN_SIZE)

        pygame.display.flip()
    pygame.quit()
